/*
	confirmation.h - A confirmation dialog
	Copyright (C) 2005  Konrad Twardowski <kdtonline@poczta.onet.pl>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __CONFIRMATION_H__
#define __CONFIRMATION_H__

#include "actions.h"

/** @short A confirmation dialog. */
class Confirmation
{
public:
	/**
	 * Displays a confirmation message box.
	 * @param action An action to confirm
	 * @param delay A selected delay
	 * @return @c true if action has been confirmed; otherwise @c false
	 */
	static bool confirm(const Action::Type action, const QString &delay);
};

#endif // __CONFIRMATION_H__
